# Filum

Filum saves discussion threads to your local machine. Think Pocket or Instapaper but for Reddit, Hacker News and Stack Exchange. 


## Features

### Supported websites

- Reddit
- Hacker News
- Stack Exchange 



